import 'dart:convert';

import 'package:firebase_messaging/firebase_messaging.dart';
import 'package:http/http.dart' as http;

class FcmNotificationService {
  final String serverKey;

  FcmNotificationService({this.serverKey}) : assert(serverKey != null);

  FirebaseMessaging _firebaseMessaging = FirebaseMessaging();

  Future<String> getToken() async {
    return await _firebaseMessaging.getToken();
  }

  Future<void> sendNotificationMessage(
    String token,
    Map<String, dynamic> notificationPayload,
  ) async {
    await _firebaseMessaging.requestNotificationPermissions(
      const IosNotificationSettings(
        sound: true,
        badge: true,
        alert: true,
        provisional: false,
      ),
    );
    await http.post(
      'https://fcm.googleapis.com/fcm/send',
      headers: <String, String>{
        'Content-Type': 'application/json',
        'Authorization': 'key=$serverKey',
      },
      body: jsonEncode(
        <String, dynamic>{
          'notification': notificationPayload,
          'priority': 'high',
          'to': token,
        },
      ),
    );
  }

  Future<void> sendDataMessage(
    String token,
    Map<String, dynamic> dataPayload,
  ) async {
    await _firebaseMessaging.requestNotificationPermissions(
      const IosNotificationSettings(
        sound: true,
        badge: true,
        alert: true,
        provisional: false,
      ),
    );
    await http.post(
      'https://fcm.googleapis.com/fcm/send',
      headers: <String, String>{
        'Content-Type': 'application/json',
        'Authorization': 'key=$serverKey',
      },
      body: jsonEncode(
        <String, dynamic>{
          'data': dataPayload,
          'priority': 'high',
          'to': token,
        },
      ),
    );
  }
}
